@@ -110,7 +110,7 @@ def get_version(binary) -> Optional[str]:
 
 
 def check_pipx_package_provides_binary(package: str, binary: str):
-    if (path := get_first_binary(binary)) :
+    if path := get_first_binary(binary):
         return os.path.join("pipx", "venvs", package, "bin", binary) in str(
             Path(path).expanduser().resolve()
         )
@@ -282,7 +282,7 @@ class AnsibleDoctorRunner(DoctorRunner):
             click.secho("ansible check timed out", fg="red")
             return
 
-        if (match := INSTANCE_PATTERN.search(result.stdout)) :
+        if match := INSTANCE_PATTERN.search(result.stdout):
             get_server_logs(self.client, self.doctor_dir, match[1])
             get_versions_from_server(self.client, self.doctor_dir, match[1])
         else:
