@@ -134,6 +134,13 @@ LaunchDarklyParams: OrgParams = {
             arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging",
         ),
+        "sdk": Profile(
+            display_name="SDK",
+            region="us-east-1",
+            arn="arn:aws:iam::223148043183:role/ops/SSHAdmin-sdk",
+            ansible_bucket="launchdarkly-sym-ansible-sdk",
+            aliases=["sdk"],
+        ),
     },
 }
 
